"use strict";
// Copyright 2018 Knowledge Expert SA
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.have = void 0;
const conditions_1 = require("../../conditions");
const wait_1 = require("../../wait");
var have;
(function (have_1) {
    have_1.no = new Proxy(have, {
        get: (have, conditionName) => (...args) => wait_1.Condition.not(have[conditionName](...args))
    });
    /* Element conditions */
    have_1.exactText = (value) => conditions_1.condition.element.hasExactText(value);
    have_1.text = (value) => conditions_1.condition.element.hasText(value);
    have_1.attribute = (name) => conditions_1.condition.element.hasAttribute(name);
    have_1.attributeWithValue = (attributeName, attributeValue) => conditions_1.condition.element.hasAttributeWithValue(attributeName, attributeValue);
    have_1.attributeWithValueContaining = (attributeName, attributeValue) => conditions_1.condition.element.hasAttributeWithValueContaining(attributeName, attributeValue);
    have_1.value = (value) => conditions_1.condition.element.hasValue(value);
    have_1.valueContaining = (expected) => conditions_1.condition.element.hasValueContaining(expected);
    have_1.cssClass = (cssClass) => conditions_1.condition.element.hasCssClass(cssClass);
    /* Collection conditions */
    have_1.size = (size) => conditions_1.condition.collection.hasSize(size);
    have_1.sizeLessThan = (size) => conditions_1.condition.collection.hasSizeLessThan(size);
    have_1.sizeLessThanOrEqual = (size) => conditions_1.condition.collection.hasSizeLessThanOrEqual(size);
    have_1.sizeGreaterThan = (size) => conditions_1.condition.collection.hasSizeGreaterThan(size);
    have_1.sizeGreaterThanOrEqual = (size) => conditions_1.condition.collection.hasSizeGreaterThanOrEqual(size);
    have_1.texts = (...texts) => conditions_1.condition.collection.hasTexts(texts);
    have_1.exactTexts = (...texts) => conditions_1.condition.collection.hasExactTexts(texts);
    have_1.url = (url) => conditions_1.condition.browser.hasUrl(url);
    /* Browser conditions */
    have_1.urlContaining = (urlPart) => conditions_1.condition.browser.hasUrlContaining(urlPart);
    have_1.title = (expected) => conditions_1.condition.browser.hasTitle(expected);
    have_1.titleContaining = (titlePart) => conditions_1.condition.browser.hasTitleContaining(titlePart);
    have_1.tabsNumber = (num) => conditions_1.condition.browser.hasTabsNumber(num);
    have_1.tabsNumberLessThan = (num) => conditions_1.condition.browser.hasTabsNumberLessThan(num);
    have_1.tabsNumberMoreThan = (num) => conditions_1.condition.browser.hasTabsNumberMoreThan(num);
    // TODO we can also do that with element or collection,
    // maybe add/reuse conditions for them also?
    have_1.jsReturned = (expected, script, ...scriptArgs) => conditions_1.condition.browser.hasJsReturned(expected, script, ...scriptArgs);
})(have = exports.have || (exports.have = {}));
//# sourceMappingURL=have.js.map